@@ -1,8 +1,8 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
  *
- * $Id: map_OSM.c,v 1.10 2010/09/24 02:24:27 jedunmire Exp $
+ * $Id: map_OSM.c,v 1.16 2012/11/01 18:57:19 we7u Exp $
  *
- * Copyright (C) 2010 The Xastir Group
+ * Copyright (C) 2010-2012 The Xastir Group
  *
  * This file was contributed by Jerry Dunmire, KA6HLD.
  *
@@ -24,7 +24,7 @@
  *
  * This file derived from map_tiger.c which has the following copyrights:
  *    Copyright (C) 1999,2000  Frank Giannandrea
- *    Copyright (C) 2000-2010  The Xastir Group
+ *    Copyright (C) 2000-2012  The Xastir Group
  */
 
 
@@ -135,13 +135,6 @@
 #undef PACKAGE_VERSION
 #define PACKAGE_VERSION XASTIR_PACKAGE_VERSION
 #undef XASTIR_PACKAGE_VERSION
-#endif // HAVE_MAGICK
-
-// Must be last include file
-#include "leak_detection.h"
-
-#define xastirColorsMatch(p,q) (((p).red == (q).red) && ((p).blue == (q).blue) \
-        && ((p).green == (q).green))
 
 // This matte color was chosen emphirically to work well with the
 // contours from topOSM.
@@ -165,6 +158,14 @@
 #error "QuantumDepth != 16 or 8"
 #endif // QuantumDepth
 
+#endif // HAVE_MAGICK
+
+// Must be last include file
+#include "leak_detection.h"
+
+#define xastirColorsMatch(p,q) (((p).red == (q).red) && ((p).blue == (q).blue) \
+        && ((p).green == (q).green))
+
 // osm_scale_x - map Xastir scale_x value to an OSM binned value
 // 
 // Note that the terms 'higher' and 'lower' are confusing because a
@@ -297,6 +298,7 @@ static void get_OSM_local_file(char * local_filename, char * fileimg){
     char *cache_file_id;
 #endif  // USE_MAP_CACHE
 
+    char temp_file_path[MAX_VALUE];
 
     if (debug_level & 512) {
         query_start_time=time(&query_start_time); 
@@ -334,7 +336,7 @@ set_dangerous("map_OSM: map_cache_fileid");
         xastir_snprintf(local_filename,
             MAX_FILENAME,           // hardcoded to avoid sizeof()
             "%s/map_%s.%s",
-            get_user_base_dir("map_cache"),
+            get_user_base_dir("map_cache", temp_file_path, sizeof(temp_file_path)),
             cache_file_id,
             "png");
         free(cache_file_id);
@@ -345,7 +347,7 @@ clear_dangerous();
     xastir_snprintf(local_filename,
         MAX_FILENAME,               // hardcoded to avoid sizeof()
         "%s/map.%s",
-         get_user_base_dir("tmp"),
+         get_user_base_dir("tmp", temp_file_path, sizeof(temp_file_path)),
         "png");
 
 #endif  // USE_MAP_CACHE
@@ -970,6 +972,7 @@ void draw_OSM_tiles (Widget w,
     char errBuf[CURL_ERROR_SIZE];
     int curl_result;
 #endif // HAVE_LIBCURL
+    char temp_file_path[MAX_VALUE];
 
     // Check whether we're indexing or drawing the map
     if ( (destination_pixmap == INDEX_CHECK_TIMESTAMPS)
@@ -1001,11 +1004,11 @@ void draw_OSM_tiles (Widget w,
                     "%s", tileCacheDir);
         } else {
             xastir_snprintf(tileRootDir, sizeof(tileRootDir),
-                    "%s", get_user_base_dir(tileCacheDir));
+                    "%s", get_user_base_dir(tileCacheDir, temp_file_path, sizeof(temp_file_path)));
         }
     } else {
         xastir_snprintf(tileRootDir, sizeof(tileRootDir),
-                "%s", get_user_base_dir("OSMtiles"));
+                "%s", get_user_base_dir("OSMtiles", temp_file_path, sizeof(temp_file_path)));
     }
     
     if (mapName[0] != '\0') {
@@ -1091,7 +1094,7 @@ void draw_OSM_tiles (Widget w,
     tileCnt = 1;
     for (tilex = tiles.startx; tilex <= tiles.endx; tilex++) {
         for (tiley = tiles.starty; tiley <= tiles.endy; tiley++) {
-            if (numTiles > 0) {
+            if ((numTiles > 0) & (tileCnt <= numTiles)) {
                 xastir_snprintf(map_it, sizeof(map_it), langcode("BBARSTA051"),
                         tileCnt, numTiles);  // Downloading tile %ls of %ls
                 statusline(map_it,0);
@@ -1239,6 +1242,8 @@ void draw_OSM_tiles (Widget w,
                         fprintf(stderr, "Removing %s\n", tmpString);
                         unlink(tmpString);
                     }
+                    // clear exception so next iteration doesn't fail
+                    GetExceptionInfo(&exception);
 
                     // replace the missing tile with a place holder
                     //(void)strcpy(tile_info->filename, "xc:red");
